Sizing

Enum Sizing 

pub enum Sizing {
    Auto,
    Px(f32),
    PercentWidth(f32),
    PercentHeight(f32),
}
Defines a size in a Style.

Options:

  • Auto - Uses whatever the default for that element in Style is.
  • Px(pixels: f32) - Returns the given pixels as this size.
  • PercentWidth(percent: f32) - Returns the percent times the display width.
  • PercentHeight(percent: f32) - Returns the percent times the display height.

Variants



Auto



Px(f32)



PercentWidth(f32)



PercentHeight(f32)

Implementations

Source

impl Sizing

pub fn size(&self, dimensions: &Vector2<f32>) -> f32

Gets the pixel size of this sizing using the given dimensions.

Arguments:

  • &self - The sizing to convert.
  • dimensions: &Vector2 - The window dimensions (or any dimensions you want IF you know what you’re doing).
pub fn is_set(&self) -> bool

Returns true if this is not Auto.