pub struct Files;Expand description
A struct to contain functions for loading files.
Implementations
Sourceimpl Files
impl Files
Sourcepub fn load_bytes(path: &str) -> Result<Vec<u8>, Error>
pub fn load_bytes(path: &str) -> Result<Vec<u8>, Error>
A function to load the bytes of a file at the given relative path.
Arguments:
- path: &str - the relative path to the file.
Returns a result:
- Ok - Vec
- The bytes of the file. - Error - std::io::Error - The io error that occured while failing to load the file.